lib/PublicInbox/SearchView.pm | 6 +++---
diff --git a/lib/PublicInbox/SearchView.pm b/lib/PublicInbox/SearchView.pm
index c42cf2d63fa3c9b99c2ce5fc534addffcebe8fd6..39400d6d4d16c7c0edfe6e97bf988fc3ab7c1540 100644
--- a/lib/PublicInbox/SearchView.pm
+++ b/lib/PublicInbox/SearchView.pm
@@ -79,7 +79,7 @@ });
}
}
# display non-threaded search results similar to what users expect from
# regular WWW search engines:
sub mset_summary {
my ($ctx, $mset, $q) = @_;
@@ -157,10 +157,10 @@
my $x = $q->{x};
if ($x eq '') {
my $t = $q->qs_html(x => 't');
- $rv .= qq{summary|threaded}
+ $rv .= qq{summary|nested}
} elsif ($q->{x} eq 't') {
my $s = $q->qs_html(x => '');
- $rv .= qq{summary|threaded};
+ $rv .= qq{summary|nested};
}
my $A = $q->qs_html(x => 'A', r => undef);
$rv .= qq{|Atom feed]};
@@ -79,7 +79,7 @@ });
}
}
-# display non-threaded search results similar to what users expect from
+# display non-nested search results similar to what users expect from
# regular WWW search engines:
sub mset_summary {